@@ -18,10 +18,10 @@ class TestMerge < Test::Unit::TestCase
       new_file('new_file_3', 'hello')
       g.add
 
-      assert(!g.status['new_file_1'])  # file is not there
+      assert(!g.status['new_file_1']) # file is not there
 
       assert(g.branch('new_branch').merge)
-      assert(g.status['new_file_1'])  # file has been merged in
+      assert(g.status['new_file_1']) # file has been merged in
     end
   end
 
@@ -44,7 +44,7 @@ class TestMerge < Test::Unit::TestCase
       end
 
       g.branch('new_branch').merge('new_branch2')
-      assert(!g.status['new_file_3'])  # still in master branch
+      assert(!g.status['new_file_3']) # still in master branch
 
       g.branch('new_branch').checkout
       assert(g.status['new_file_3'])  # file has been merged in
@@ -52,7 +52,6 @@ class TestMerge < Test::Unit::TestCase
       g.branch('master').checkout
       g.merge(g.branch('new_branch'))
       assert(g.status['new_file_3'])  # file has been merged in
-
     end
   end
 
@@ -77,11 +76,10 @@ class TestMerge < Test::Unit::TestCase
       assert(!g.status['new_file_1'])  # still in master branch
       assert(!g.status['new_file_3'])  # still in master branch
 
-      g.merge(['new_branch', 'new_branch2'])
+      g.merge(%w[new_branch new_branch2])
 
       assert(g.status['new_file_1'])  # file has been merged in
       assert(g.status['new_file_3'])  # file has been merged in
-
     end
   end
 
